@@ -54,16 +54,15 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <libbonobo.h>
 #include <gconf/gconf-client.h>
 #include <libgnomeui/gnome-help.h>
-#include <libgnome/gnome-init.h>
 #include <libgnomeui/gnome-url.h>
 
 #ifdef HAVE_LIBECAL
 #include "calendar-client.h"
 #endif
 
+#define CLOCK_ICON "gnome-panel-clock"
 #define INTERNETSECOND (864)
 #define INTERNETBEAT   (86400)
 
@@ -144,6 +143,7 @@ struct _ClockData {
 	guint              timeout;
 	PanelAppletOrient  orient;
 	int                size;
+	GtkAllocation      old_allocation;
 
 	int fixed_width;
 	int fixed_height;
@@ -179,6 +179,7 @@ static void display_about_dialog      (BonoboUIComponent *uic,
 static void position_calendar_popup   (ClockData         *cd,
                                        GtkWidget         *window,
                                        GtkWidget         *button);
+static void update_orient (ClockData *cd);
 
 static void
 unfix_size (ClockData *cd)
@@ -188,6 +189,35 @@ unfix_size (ClockData *cd)
 	gtk_widget_queue_resize (cd->toggle);
 }
 
+static int
+calculate_minimum_width (GtkWidget   *widget,
+			 const gchar *text)
+{
+	PangoContext *context;
+	PangoLayout  *layout;
+	int	      width, height;
+	int	      focus_width = 0;
+	int	      focus_pad = 0;
+
+	context = gtk_widget_get_pango_context (widget);
+
+	layout = pango_layout_new (context);
+	pango_layout_set_alignment (layout, PANGO_ALIGN_LEFT);
+	pango_layout_set_text (layout, text, -1);
+	pango_layout_get_pixel_size (layout, &width, &height);
+	g_object_unref (G_OBJECT (layout));
+	layout = NULL;
+
+	gtk_widget_style_get (widget,
+			      "focus-line-width", &focus_width,
+			      "focus-padding", &focus_pad,
+			      NULL);
+
+	width += 2 * (focus_width + focus_pad + widget->style->xthickness);
+
+	return width;
+}
+
 static void
 set_tooltip (GtkWidget  *applet,
 	     GtkWidget  *widget,
@@ -291,7 +321,7 @@ calculate_minimum_height (GtkWidget        *widget,
 static gboolean
 use_two_line_format (ClockData *cd)
 {
-        if (cd->size >= 2 * calculate_minimum_height (cd->applet, cd->orient))
+        if (cd->size >= 2 * calculate_minimum_height (cd->toggle, cd->orient))
                 return TRUE;
 
         return FALSE;
@@ -412,7 +442,8 @@ update_clock (ClockData * cd)
 	gtk_label_set_text (GTK_LABEL (cd->clockw), utf8);
 	g_free (utf8);
 
-        gtk_widget_queue_resize (cd->toggle);
+	update_orient (cd);
+	gtk_widget_queue_resize (cd->toggle);
 
         if (!cd->showdate) {
                 /* Show date in tooltip */
@@ -640,10 +671,9 @@ format_time (ClockFormat format,
         }
 
         strftime (result, sizeof (result), time_format, tm);
-
         g_free (time_format);
 
-        return g_strdup (result);
+        return g_locale_to_utf8 (result, -1, NULL, NULL, NULL);
 }
 
 static void
@@ -1402,6 +1432,7 @@ create_calendar (ClockData *cd,
         struct tm                 *tm;
 
 	window = GTK_WINDOW (gtk_window_new (GTK_WINDOW_TOPLEVEL));
+	gtk_window_set_icon_name (window, CLOCK_ICON);
         gtk_window_set_screen (window, screen);
 
         frame = gtk_frame_new (NULL);
@@ -1692,14 +1723,6 @@ create_clock_widget (ClockData *cd)
 
 	cd->orient = panel_applet_get_orient (PANEL_APPLET (cd->applet));
 
-	/* Initialize label orientation */
-	if (cd->orient == PANEL_APPLET_ORIENT_RIGHT)
-		gtk_label_set_angle (GTK_LABEL (cd->clockw), 90);
-	else if (cd->orient == PANEL_APPLET_ORIENT_LEFT)
-		gtk_label_set_angle (GTK_LABEL (cd->clockw), 270);
-	else
-		gtk_label_set_angle (GTK_LABEL (cd->clockw), 0);
-
 	cd->size = panel_applet_get_size (PANEL_APPLET (cd->applet));
 
 	g_signal_connect (G_OBJECT(clock), "destroy",
@@ -1713,22 +1736,44 @@ create_clock_widget (ClockData *cd)
 	refresh_clock_timeout(cd);
 }
 
-/* this is when the panel orientation changes */
+static void
+update_orient (ClockData *cd)
+{
+	const gchar *text;
+	int          min_width;
+	gdouble      new_angle;
+	gdouble      angle;
 
+	text = gtk_label_get_text (GTK_LABEL (cd->clockw));
+	min_width = calculate_minimum_width (cd->toggle, text);
+
+	if (cd->orient == PANEL_APPLET_ORIENT_LEFT &&
+	    min_width > cd->toggle->allocation.width)
+		new_angle = 270;
+	else if (cd->orient == PANEL_APPLET_ORIENT_RIGHT &&
+		 min_width > cd->toggle->allocation.width)
+		new_angle = 90;
+	else
+		new_angle = 0;
+
+	angle = gtk_label_get_angle (GTK_LABEL (cd->clockw));
+	if (angle != new_angle) {
+		unfix_size (cd);
+		gtk_label_set_angle (GTK_LABEL (cd->clockw), new_angle);
+	}
+}
+
+/* this is when the panel orientation changes */
 static void
 applet_change_orient (PanelApplet       *applet,
 		      PanelAppletOrient  orient,
 		      ClockData         *cd)
 {
+	if (orient == cd->orient)
+		return;
+
         cd->orient = orient;
         
-        if (cd->orient == PANEL_APPLET_ORIENT_RIGHT)
-                gtk_label_set_angle (GTK_LABEL (cd->clockw), 90);
-        else if (cd->orient == PANEL_APPLET_ORIENT_LEFT)
-                gtk_label_set_angle (GTK_LABEL (cd->clockw), 270);
-        else
-                gtk_label_set_angle (GTK_LABEL (cd->clockw), 0);
-	
         unfix_size (cd);
         update_clock (cd);
         update_popup (cd);
@@ -1736,21 +1781,25 @@ applet_change_orient (PanelApplet       *applet,
 
 /* this is when the panel size changes */
 static void
-applet_change_pixel_size (PanelApplet   *applet,
+toggle_change_pixel_size (GtkWidget     *widget,
 			  GtkAllocation *allocation,
-			  ClockData     *cd)
+			  ClockData	*cd)
 {
 	int new_size;
 
-        if (cd->orient == PANEL_APPLET_ORIENT_LEFT ||
+	if (cd->old_allocation.width  == allocation->width &&
+	    cd->old_allocation.height == allocation->height)
+		return;
+
+	cd->old_allocation.width  = allocation->width;
+	cd->old_allocation.height = allocation->height;
+
+	if (cd->orient == PANEL_APPLET_ORIENT_LEFT ||
 	    cd->orient == PANEL_APPLET_ORIENT_RIGHT)
 		new_size = allocation->width;
 	else
 		new_size = allocation->height;
 
-	if (cd->size == new_size)
-		return;
-
 	cd->size = new_size;
 
         unfix_size (cd);
@@ -1891,7 +1940,8 @@ try_config_tool (GdkScreen  *screen,
 		
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (gtk_widget_destroy), NULL);
-			
+
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), CLOCK_ICON);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
 			
@@ -1928,6 +1978,7 @@ config_date (BonoboUIComponent *uic,
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (gtk_widget_destroy), NULL);
 		
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), CLOCK_ICON);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
 
@@ -2293,7 +2344,9 @@ fill_clock_applet (PanelApplet *applet)
 	gtk_container_set_border_width (GTK_CONTAINER (cd->toggle), 0);
 	gtk_container_add (GTK_CONTAINER (cd->applet), cd->toggle);
 
-	gtk_window_set_default_icon_name ("clock");
+#ifndef CLOCK_INPROCESS
+	gtk_window_set_default_icon_name (CLOCK_ICON);
+#endif
 	gtk_widget_show (cd->applet);
 
 	/* FIXME: Update this comment. */
@@ -2305,9 +2358,9 @@ fill_clock_applet (PanelApplet *applet)
 			  G_CALLBACK (applet_change_orient),
 			  cd);
 
-	g_signal_connect (G_OBJECT (cd->applet),
-			  "size-allocate",
-			  G_CALLBACK (applet_change_pixel_size),
+	g_signal_connect (G_OBJECT (cd->toggle),
+			  "size_allocate",
+			  G_CALLBACK (toggle_change_pixel_size),
 			  cd);
 
 	panel_applet_set_background_widget (PANEL_APPLET (cd->applet),
@@ -2531,6 +2584,8 @@ properties_response_cb (GtkWidget *widget,
 					  G_CALLBACK (gtk_widget_destroy),
 					  NULL);
 
+			gtk_window_set_icon_name (GTK_WINDOW (dialog),
+						  CLOCK_ICON);
 			gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 			gtk_window_set_screen (GTK_WINDOW (dialog),
 					       gtk_widget_get_screen (cd->applet));
@@ -2566,6 +2621,7 @@ display_properties_dialog (BonoboUIComponent *uic,
 						 GTK_RESPONSE_CLOSE,
 						 NULL);
 
+	gtk_window_set_icon_name (GTK_WINDOW (cd->props), CLOCK_ICON);
 	gtk_dialog_set_has_separator (GTK_DIALOG (cd->props), FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG (cd->props), GTK_RESPONSE_CLOSE);
 	gtk_window_set_resizable (GTK_WINDOW (cd->props), FALSE);
@@ -2705,6 +2761,7 @@ display_help_dialog (BonoboUIComponent *uic,
 				  G_CALLBACK (gtk_widget_destroy),
 				  NULL);
 
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), CLOCK_ICON);
 		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 		gtk_window_set_screen (GTK_WINDOW (dialog),
 				       gtk_widget_get_screen (cd->applet));
@@ -2746,9 +2803,10 @@ display_about_dialog (BonoboUIComponent *uic,
 		      "authors", authors,
 		      "documenters", documenters,
 		      "translator-credits", _("translator-credits"),
-		      "logo-icon-name", "clock",
+		      "logo-icon-name", CLOCK_ICON,
 		      NULL);
 	
+	gtk_window_set_icon_name (GTK_WINDOW (cd->about), CLOCK_ICON);
 	gtk_window_set_wmclass (GTK_WINDOW (cd->about), "clock", "Clock");
 	gtk_window_set_screen (GTK_WINDOW (cd->about),
 			       gtk_widget_get_screen (cd->applet));
@@ -2776,9 +2834,17 @@ clock_factory (PanelApplet *applet,
 	return retval;
 }
 
+#ifdef CLOCK_INPROCESS
+PANEL_APPLET_BONOBO_SHLIB_FACTORY ("OAFIID:GNOME_ClockApplet_Factory",
+				   PANEL_TYPE_APPLET,
+				   "ClockApplet",
+				   clock_factory,
+				   NULL);
+#else
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_ClockApplet_Factory",
                              PANEL_TYPE_APPLET,
                              "ClockApplet",
                              "0",
                              clock_factory,
                              NULL);
+#endif
