@@ -25,6 +25,7 @@
 #include "panel-stock-icons.h"
 #include "panel-action-protocol.h"
 #include "panel-lockdown.h"
+#include "xstuff.h"
 
 #include "nothing.cP"
 
@@ -89,6 +90,8 @@ main (int argc, char **argv)
 			 (GFunc)panel_widget_add_forbidden,
 			 NULL);
 
+	xstuff_init ();
+
 	gtk_main ();
 
 	panel_lockdown_finalize ();
