@@ -311,7 +311,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, size_change),
                               NULL,
                               NULL, 
-                              panel_marshal_VOID__VOID,
+                              g_cclosure_marshal_VOID__VOID,
                               G_TYPE_NONE,
                               0);
 
@@ -322,7 +322,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, back_change),
                               NULL,
                               NULL, 
-                              panel_marshal_VOID__VOID,
+                              g_cclosure_marshal_VOID__VOID,
                               G_TYPE_NONE,
                               0);
 
@@ -333,7 +333,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, applet_move),
                               NULL,
                               NULL, 
-                              panel_marshal_VOID__POINTER,
+                              g_cclosure_marshal_VOID__POINTER,
                               G_TYPE_NONE,
                               1,
                               G_TYPE_POINTER); 
@@ -345,7 +345,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, applet_added),
                               NULL,
                               NULL, 
-                              panel_marshal_VOID__POINTER,
+                              g_cclosure_marshal_VOID__POINTER,
                               G_TYPE_NONE,
                               1,
                               G_TYPE_POINTER); 
@@ -357,7 +357,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, applet_removed),
                               NULL,
                               NULL, 
-                              panel_marshal_VOID__POINTER,
+                              g_cclosure_marshal_VOID__POINTER,
                               G_TYPE_NONE,
                               1,
                               G_TYPE_POINTER); 
@@ -405,7 +405,7 @@ panel_widget_class_init (PanelWidgetClass *class)
 			      G_STRUCT_OFFSET (PanelWidgetClass, tab_move),
                               NULL,
                               NULL,
-                              panel_marshal_VOID__BOOLEAN,
+                              g_cclosure_marshal_VOID__BOOLEAN,
                               G_TYPE_NONE,
                               1,
                               G_TYPE_BOOLEAN);
@@ -417,7 +417,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_STRUCT_OFFSET (PanelWidgetClass, end_move),
                               NULL,
                               NULL,
-                              panel_marshal_VOID__VOID,
+                              g_cclosure_marshal_VOID__VOID,
                               G_TYPE_NONE,
                               0);
 
@@ -1322,8 +1322,6 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	GList *list;
 	int i;
 	int old_size;
-	int old_thick;
-	GtkAllocation old_alloc;
 
 	g_return_if_fail(PANEL_IS_WIDGET(widget));
 	g_return_if_fail(allocation!=NULL);
@@ -1331,10 +1329,7 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	panel = PANEL_WIDGET(widget);
 
 	old_size = panel->size;
-	old_thick = panel->thick;
 	
-	old_alloc = widget->allocation;
-
 	widget->allocation = *allocation;
 	if (GTK_WIDGET_REALIZED (widget))
 		gdk_window_move_resize (widget->window,
@@ -2010,9 +2005,6 @@ panel_widget_nice_move (PanelWidget *panel,
 			AppletData  *ad,
 			int          pos)
 {
-	AppletData *pad1 = NULL, *pad2 = NULL;
-	GList      *l;
-	
 	g_return_if_fail (PANEL_IS_WIDGET (panel));
 	g_return_if_fail (ad != NULL);
 
@@ -2020,22 +2012,12 @@ panel_widget_nice_move (PanelWidget *panel,
 	if (pos < 0 || pos == ad->pos)
 		return;
 
-	l = g_list_find (panel->applet_list, ad);
-	if (l && l->prev) {
-		pad1 = l->prev->data;
-	}
-
 	ad->pos = ad->constrained = pos;
 
 	panel->applet_list =
 		panel_g_list_resort_item (panel->applet_list, ad,
 					  (GCompareFunc)applet_data_compare);
 
-	l = g_list_find (panel->applet_list, ad);
-	if (l && l->prev) {
-		pad2 = l->prev->data;
-	}
-
 	gtk_widget_queue_resize (GTK_WIDGET (panel));
 
 	emit_applet_moved (panel, ad);
@@ -2645,6 +2627,7 @@ panel_widget_background_changed (PanelBackground *background,
 				 PanelWidget     *panel)
 {
 	g_return_if_fail (PANEL_IS_WIDGET (panel));
+	panel_toplevel_update_edges (panel->toplevel);
 	g_signal_emit (G_OBJECT (panel),
 		       panel_widget_signals [BACK_CHANGE_SIGNAL],
 		       0);
